"""Add registry as ferda plugin."""
from django.urls import reverse_lazy
from django.utils.translation import gettext_lazy as _

from ferda.plugins import PluginConfig, register

registry_plugin_config = PluginConfig(
    name=_('Registry'),
    url=reverse_lazy('registry:search:search'),
    icon='mdi-earth',
    access=lambda user: user.has_perm('ferda.can_view_registry'),
)

notification_plugin_config = PluginConfig(
    name=_('Notifications'),
    url=reverse_lazy('notification:index'),
    access=lambda user: user.has_perms(('ferda.can_update_additional_contacts', 'ferda.can_view_registry')),
)

messages_plugin_config = PluginConfig(
    name=_('Messages'),
    url=reverse_lazy('messages:list'),
    icon='mdi-email',
    access=lambda user: user.has_perm('ferda.can_view_registry'),
)

reports_plugin_config = PluginConfig(
    name=_('Reports'),
    url=reverse_lazy('reports:list'),
    icon='mdi-package-variant-closed',
    access=lambda user: user.has_perm('ferda.view_report'),
)

logger_plugin_config = PluginConfig(
    name=_('Logger'),
    url=reverse_lazy('logger:index'),
    icon='mdi-post-outline',
    access=lambda user: user.has_perm('ferda.can_view_registry'),
)

# Modules are displayed in reversed order in application menu
register('logger', logger_plugin_config)
register('reports', reports_plugin_config)
register('messages', messages_plugin_config)
register('notification', notification_plugin_config)
register('registry', registry_plugin_config)
