"""Tests for proper URL resolving."""
from typing import List, Tuple

from django.test import TestCase, override_settings
from django.urls import resolve


@override_settings(ROOT_URLCONF='ferda.tests.urls')
class ApiUrlTest(TestCase):
    """Test class for forward URL resolving of API endpoints."""

    def test_forward_url_resolving_representative(self):
        """Test representative URLs."""
        data: List[Tuple[str, str]] = [  # (URL part, API endpoint url_name in namespace)
            ("/", "add_representative"),  # POST
            ("/representative-id-1/", "representative"),  # GET, PUT, DELETE
            ("/representative-id-1/history/", "representative_history"),  # GET
            ("/representative-id-1/contact/", "representative_contact"),  # GET
        ]
        for url, reverse_url in data:
            with self.subTest(url=url):
                self.assertEqual(resolve("/api/registry/representative" + url).view_name, "api-1:" + reverse_url)
